"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const color_1 = require("@heroku-cli/color");
const base_1 = tslib_1.__importDefault(require("../../../lib/base"));
const command_1 = require("@heroku-cli/command");
const Integration = tslib_1.__importStar(require("../../../lib/integration/types"));
const core_1 = require("@oclif/core");
const helpers_1 = require("../../../lib/helpers");
class Index extends base_1.default {
    static description = 'lists Heroku Integration connections';
    static flags = {
        app: command_1.flags.app(),
        remote: command_1.flags.remote(),
    };
    async run() {
        const { flags } = await this.parse(Index);
        const { app } = flags;
        let appConnections = [];
        if (app) {
            await this.configureIntegrationClient(app);
            ({ body: appConnections } = await this.integration.get(`/addons/${this.addonId}/connections`));
        }
        else {
            const integrationAddons = await this.getIntegrationAddons();
            appConnections = integrationAddons.length > 0 ? (await this.getAppConnections(integrationAddons)) : [];
        }
        if (appConnections.length === 0) {
            core_1.ux.log(`No Heroku Integration connections${app ? ` for app ${color_1.color.app(app)}` : ''}.`);
        }
        else {
            core_1.ux.styledHeader(`Heroku Integration connections${app ? ` for app ${color_1.color.app(app)}` : ''}`);
            core_1.ux.table(appConnections, {
                ...(app ? {} : { app: { get: row => row.app?.name } }),
                type: { get: row => (0, helpers_1.humanize)(Integration.adjustConnectionType(row.type)) },
                orgName: {
                    header: 'Org Name',
                    get: row => Integration.isSalesforceConnection(row) ? row.salesforce_org.org_name : row.datacloud_org.org_name,
                },
                state: { get: row => (0, helpers_1.humanize)(row.state) },
                runAsUser: {
                    header: 'Run As User',
                    get: row => Integration.isSalesforceConnection(row) ? row.salesforce_org.run_as_user : row.datacloud_org.run_as_user,
                },
            });
        }
    }
    async getIntegrationAddons() {
        const { body: addons } = await this.heroku.get('/addons');
        return addons.filter(addon => addon.addon_service?.name === this.addonServiceSlug);
    }
    async getAppConnections(integrationAddons) {
        const appConnections = [];
        for (const addonsSlice of (0, helpers_1.arraySlice)(integrationAddons)) {
            const appConnectionListUrls = await this.getAppConnectionListUrls(addonsSlice);
            const connectionListPromises = appConnectionListUrls.map(appConnectionListUrl => {
                return this.heroku.get(appConnectionListUrl.url, { host: new URL(appConnectionListUrl.url).hostname });
            });
            const connectionListResponses = await Promise.all(connectionListPromises);
            connectionListResponses.forEach((response, index) => {
                const connections = response.body;
                connections.forEach(connection => {
                    appConnections.push({
                        app: addonsSlice[index].app,
                        ...connection,
                    });
                });
            });
        }
        return appConnections;
    }
    async getAppConnectionListUrls(integrationAddons) {
        const configVarPromises = integrationAddons.map(addon => this.heroku.get(`/apps/${addon.app.id}/config-vars`));
        const configVarsResponses = await Promise.all(configVarPromises);
        const appConnectionListUrls = [];
        configVarsResponses.forEach((response, index) => {
            const apiUrl = response.body[this.apiUrlConfigVarName];
            if (apiUrl)
                appConnectionListUrls.push({
                    url: `${apiUrl}/connections`,
                    app: integrationAddons[index].app,
                });
        });
        return appConnectionListUrls;
    }
}
exports.default = Index;
