"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const color_1 = require("@heroku-cli/color");
const base_1 = tslib_1.__importDefault(require("../../../lib/base"));
const command_1 = require("@heroku-cli/command");
const Integration = tslib_1.__importStar(require("../../../lib/integration/types"));
const core_1 = require("@oclif/core");
const helpers_1 = require("../../../lib/helpers");
class Info extends base_1.default {
    static description = 'shows info for a Heroku Integration connection';
    static flags = {
        app: command_1.flags.app({ required: true }),
        remote: command_1.flags.remote(),
    };
    static args = {
        org_name: core_1.Args.string({ description: 'connected org name', required: true }),
    };
    async run() {
        const { flags, args } = await this.parse(Info);
        const { app } = flags;
        const { org_name: orgName } = args;
        await this.configureIntegrationClient(app);
        let connection;
        try {
            ({ body: connection } = await this.integration.get(`/addons/${this.addonId}/connections/${orgName}`));
        }
        catch (error) {
            const connErr = error;
            if (connErr.body && connErr.body.id === 'record_not_found') {
                core_1.ux.error(`Data Cloud org ${color_1.color.yellow(orgName)} not found or not connected to app ${color_1.color.app(app)}`, { exit: 1 });
            }
            else {
                throw error;
            }
        }
        const orgInfo = Integration.isSalesforceConnection(connection) ? connection.salesforce_org : connection.datacloud_org;
        core_1.ux.styledObject({
            Id: connection.id,
            'Instance URL': orgInfo.instance_url,
            'Org ID': orgInfo.id,
            'Org Name': orgInfo.org_name,
            'Run As User': orgInfo.run_as_user,
            State: (0, helpers_1.humanize)(connection.state),
            Type: (0, helpers_1.humanize)(Integration.adjustConnectionType(connection.type)),
        });
    }
}
exports.default = Info;
