"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const color_1 = require("@heroku-cli/color");
const base_1 = tslib_1.__importDefault(require("../../lib/base"));
const command_1 = require("@heroku-cli/command");
const core_1 = require("@oclif/core");
const helpers_1 = require("../../lib/helpers");
const tsheredoc_1 = tslib_1.__importDefault(require("tsheredoc"));
class Disconnect extends base_1.default {
    static description = 'disconnects a Salesforce Org from a Heroku app';
    static flags = {
        app: command_1.flags.app({ required: true }),
    };
    static args = {
        org_name: core_1.Args.string({ description: 'Salesforce Org instance name', required: true }),
    };
    async run() {
        const { flags, args } = await this.parse(Disconnect);
        const { app } = flags;
        const { org_name: orgName } = args;
        await this.configureIntegrationClient(app);
        let connection;
        try {
            ({ body: connection } = await this.integration.delete(`/addons/${this.addonId}/connections/${orgName}`));
        }
        catch (error) {
            const connErr = error;
            if (connErr.body && connErr.body.id === 'record_not_found') {
                core_1.ux.error(`Salesforce org ${color_1.color.yellow(orgName)} not found or not connected to app ${color_1.color.app(app)}`, { exit: 1 });
            }
            else {
                throw error;
            }
        }
        core_1.ux.action.start(`Disconnecting Salesforce Org ${color_1.color.yellow(orgName)} from ${color_1.color.app(app)}`);
        const { state, error } = connection;
        if (state !== 'disconnecting') {
            core_1.ux.error(error === undefined ?
                (0, helpers_1.humanize)(state) :
                (0, tsheredoc_1.default) `
            ${error.id}
            ${error.message}
          `, { exit: 1 });
        }
        core_1.ux.action.stop((0, helpers_1.humanize)('Disconnected'));
    }
}
exports.default = Disconnect;
